<?php

declare(strict_types=1);

namespace apexl\Io\modules\user\services;

use apexl\Io\modules\user\interfaces\UserPasswordVerifierInterface;

final readonly class PasswordVerifyUserPasswordVerifier implements UserPasswordVerifierInterface
{
    public function verify(string $password, string $hash): bool
    {
        return password_verify($password, $hash);
    }
}